@@ -32,8 +32,9 @@ protected:
     void makeSensors() override;
 
 private:
+    void discoverSensors();
+
     udev_device *m_device;
     QVector<KSysGuard::SysFsSensor*> m_sysFsSensors;
-    QString m_coreTemperatureCurrentPath;
-    QString m_coreTemperatureMaxPath;
+    QVector<KSysGuard::SensorProperty*> m_sensorsSensors;
 };
