@@ -7,12 +7,9 @@
 
 #include "daemon.h"
 
+#include <algorithm>
 #include <chrono>
 
-#ifdef HAVE_SENSORS
-#include <sensors/sensors.h>
-#endif
-
 #include <QDBusArgument>
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -31,6 +28,10 @@
 #include <KPluginMetaData>
 #include <KPluginFactory>
 
+#ifdef Q_OS_LINUX
+#include <sensors/sensors.h>
+#endif
+
 #include "ksystemstatsadaptor.h"
 
 #include "client.h"
@@ -63,14 +64,14 @@ Daemon::~Daemon()
     for (Client* c : m_clients) {
         delete c;
     }
-#ifdef HAVE_SENSORS
+#ifdef Q_OS_LINUX
     sensors_cleanup();
 #endif
 }
 
 void Daemon::init(ReplaceIfRunning replaceIfRunning)
 {
-#ifdef HAVE_SENSORS
+#ifdef Q_OS_LINUX
     sensors_init(nullptr);
 #endif
     loadProviders();
@@ -90,40 +91,36 @@ void Daemon::setQuitOnLastClientDisconnect(bool quit)
 
 void Daemon::loadProviders()
 {
-    //instantiate all plugins
-    QSet<QString> knownPlugins;
-    std::for_each(m_providers.cbegin(), m_providers.cend(), [&knownPlugins] (const KSysGuard::SensorPlugin *plugin) {
-        knownPlugins.insert(plugin->providerName());
-    });
-    const auto plugins = KPluginLoader::instantiatePlugins(QStringLiteral("ksystemstats"), [this, &knownPlugins](const KPluginMetaData &metaData) {
-        auto providerName = metaData.rawData().value("providerName").toString();
-        if (knownPlugins.contains(providerName)) {
-            return false;
-        }
-        knownPlugins.insert(providerName);
-        return true;
-    }, this);
-
-    for (auto object : plugins) {
-        auto factory = qobject_cast<KPluginFactory*>(object);
-        if (!factory) {
-            qWarning() << "Plugin object" << object << "did not provide a proper KPluginFactory";
-            continue;
-        }
-        auto provider = factory->create<KSysGuard::SensorPlugin>(this);
-        if (!provider) {
-            qWarning() << "Plugin object" << object << "did not provide a proper SensorPlugin";
-            continue;
-        }
-        registerProvider(provider);
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("ksystemstats"));
+    if (plugins.isEmpty()) {
+        qWarning() << "No plugins found";
     }
 
-    if (m_providers.isEmpty()) {
-        qWarning() << "No plugins found";
+    for (const KPluginMetaData &metaData : plugins) {
+        KPluginLoader pluginLoader(metaData.fileName());
+        KSysGuard::SensorPlugin *provider = nullptr;
+        if (KPluginFactory *factory = pluginLoader.factory()) {
+            provider = factory->create<KSysGuard::SensorPlugin>(this);
+            if (provider) {
+                registerProvider(provider);
+            }
+        }
+        if (!provider) {
+            qWarning() << "Could not load plugin:" << metaData.pluginId() << "with file name" << metaData.fileName();
+        } else {
+            qDebug() << "Loaded plugin" << metaData.pluginId() << "from file" << metaData.fileName();
+        }
     }
 }
 
 void Daemon::registerProvider(KSysGuard::SensorPlugin *provider) {
+    bool alreadyHasProvider = std::any_of(m_providers.begin(), m_providers.end(), [provider](KSysGuard::SensorPlugin *provider2){
+        return provider2->providerName() == provider->providerName();
+    });
+    if (alreadyHasProvider) {
+        qWarning() << "Provider" << provider->providerName() << "is already registered";
+        return;
+    }
     m_providers.append(provider);
     const auto containers = provider->containers();
     for (auto container : containers) {
